@@ -28,13 +28,12 @@
 #include <libdmapsharing/dmap-db.h>
 
 G_BEGIN_DECLS
-
 /**
- * TYPE_DAAP_RECORD:
+ * DAAP_TYPE_RECORD:
  *
  * The type for #DAAPRecord.
  */
-#define TYPE_DAAP_RECORD	     (daap_record_get_type ())
+#define DAAP_TYPE_RECORD	     (daap_record_get_type ())
 /**
  * DAAP_RECORD:
  * @o: Object which is subject to casting.
@@ -44,15 +43,15 @@ G_BEGIN_DECLS
  * certain runtime checks to identify invalid casts.
  */
 #define DAAP_RECORD(o)		     (G_TYPE_CHECK_INSTANCE_CAST ((o), \
-				      TYPE_DAAP_RECORD, DAAPRecord))
+				      DAAP_TYPE_RECORD, DAAPRecord))
 /**
  * IS_DAAP_RECORD:
- * @o: Instance to check for being a %TYPE_DAAP_RECORD.
+ * @o: Instance to check for being a %DAAP_TYPE_RECORD.
  *
- * Checks whether a valid #GTypeInstance pointer is of type %TYPE_DAAP_RECORD.
+ * Checks whether a valid #GTypeInstance pointer is of type %DAAP_TYPE_RECORD.
  */
 #define IS_DAAP_RECORD(o)	     (G_TYPE_CHECK_INSTANCE_TYPE ((o), \
-				      TYPE_DAAP_RECORD))
+				      DAAP_TYPE_RECORD))
 /**
  * DAAP_RECORD_GET_INTERFACE:
  * @o: a #DAAPRecord instance.
@@ -62,19 +61,19 @@ G_BEGIN_DECLS
  * Returns: pointer to object interface structure.
  */
 #define DAAP_RECORD_GET_INTERFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), \
-				      TYPE_DAAP_RECORD, DAAPRecordInterface))
-
+				      DAAP_TYPE_RECORD, DAAPRecordIface))
 typedef struct _DAAPRecord DAAPRecord;
-typedef struct _DAAPRecordInterface DAAPRecordInterface;
+typedef struct _DAAPRecordIface DAAPRecordIface;
 
-struct _DAAPRecordInterface {
+struct _DAAPRecordIface
+{
 	GTypeInterface parent;
 
-	gboolean	(*itunes_compat) (DAAPRecord *record);
-	GInputStream *	(*read)	         (DAAPRecord *record, GError **err);
+	  gboolean (*itunes_compat) (DAAPRecord * record);
+	GInputStream *(*read) (DAAPRecord * record, GError ** err);
 };
 
-GType         daap_record_get_type      (void);
+GType daap_record_get_type (void);
 
 /**
  * daap_record_itunes_compat:
@@ -82,7 +81,7 @@ GType         daap_record_get_type      (void);
  *
  * Returns: TRUE if record is compatible with iTunes, else FALSE.
  */
-gboolean      daap_record_itunes_compat (DAAPRecord *record);
+gboolean daap_record_itunes_compat (DAAPRecord * record);
 
 /**
  * daap_record_read:
@@ -92,7 +91,7 @@ gboolean      daap_record_itunes_compat (DAAPRecord *record);
  * Returns: A GInputStream that provides read-only access to the data stream
  * associated with record.
  */
-GInputStream *daap_record_read          (DAAPRecord *record, GError **err);
+GInputStream *daap_record_read (DAAPRecord * record, GError ** err);
 
 /**
  * daap_record_cmp_by_album:
@@ -102,8 +101,8 @@ GInputStream *daap_record_read          (DAAPRecord *record, GError **err);
  *
  * Compares the two records associated with the provided keys according
  * to album. Suitable to sort lists of albums.
- */ 
-gint daap_record_cmp_by_album (gpointer a, gpointer b, DMAPDb *db);
+ */
+gint daap_record_cmp_by_album (gpointer a, gpointer b, DMAPDb * db);
 
 #endif /* __DAAP_RECORD_H */
 
