@@ -33,7 +33,6 @@
 #include "dmap-md5.h"
 #include "dmap-connection.h"
 #include "dmap-record-factory.h"
-#include "dmap-marshal.h"
 
 #define DMAP_USER_AGENT "iTunes/4.6 (Windows; N)"
 
@@ -54,9 +53,6 @@ static void dmap_connection_state_done (DMAPConnection * connection,
 
 static gboolean emit_progress_idle (DMAPConnection * connection);
 
-G_DEFINE_TYPE (DMAPConnection, dmap_connection, G_TYPE_OBJECT);
-#define DMAP_CONNECTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DMAP_TYPE_CONNECTION, DMAPConnectionPrivate))
-
 struct DMAPConnectionPrivate
 {
 	char *name;
@@ -97,6 +93,8 @@ struct DMAPConnectionPrivate
 	char *last_error_message;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (DMAPConnection, dmap_connection, G_TYPE_OBJECT);
+
 enum
 {
 	PROP_0,
@@ -158,8 +156,6 @@ dmap_connection_class_init (DMAPConnectionClass * klass)
 	object_class->set_property = dmap_connection_set_property;
 	object_class->get_property = dmap_connection_get_property;
 
-	g_type_class_add_private (klass, sizeof (DMAPConnectionPrivate));
-
 	g_object_class_install_property (object_class,
 					 PROP_DB,
 					 g_param_spec_pointer ("db",
@@ -262,7 +258,7 @@ dmap_connection_class_init (DMAPConnectionClass * klass)
 					      G_STRUCT_OFFSET
 					      (DMAPConnectionClass,
 					       authenticate), NULL, NULL,
-					      dmap_marshal_VOID__STRING_POINTER_POINTER_POINTER_BOOLEAN,
+					      NULL,
 					      G_TYPE_NONE, 5,
 					      G_TYPE_STRING,
 					      SOUP_TYPE_SESSION,
@@ -274,34 +270,34 @@ dmap_connection_class_init (DMAPConnectionClass * klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (DMAPConnectionClass,
 					       connecting), NULL, NULL,
-			      dmap_marshal_VOID__ULONG_FLOAT, G_TYPE_NONE, 2,
+			      NULL, G_TYPE_NONE, 2,
 			      G_TYPE_ULONG, G_TYPE_FLOAT);
 	signals[CONNECTED] =
 		g_signal_new ("connected", G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (DMAPConnectionClass,
 					       connected), NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
+			      NULL, G_TYPE_NONE, 0);
 	signals[DISCONNECTED] =
 		g_signal_new ("disconnected",
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (DMAPConnectionClass,
 					       disconnected), NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
+			      NULL, G_TYPE_NONE, 0);
 	signals[OPERATION_DONE] =
 		g_signal_new ("operation-done",
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (DMAPConnectionClass,
 					       operation_done), NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
+			      NULL, G_TYPE_NONE, 0);
 }
 
 static void
 dmap_connection_init (DMAPConnection * connection)
 {
-	connection->priv = DMAP_CONNECTION_GET_PRIVATE (connection);
+	connection->priv = dmap_connection_get_instance_private(connection);
 }
 
 static void
@@ -341,9 +337,10 @@ connection_operation_done (DMAPConnection * connection)
 SoupMessage *
 dmap_connection_build_message (DMAPConnection * connection,
 			       const char *path,
-			       gboolean need_hash,
-			       gdouble version,
-			       gint req_id, gboolean send_close)
+			       G_GNUC_UNUSED gboolean need_hash,
+			       G_GNUC_UNUSED gdouble version,
+			       G_GNUC_UNUSED gint req_id,
+                               G_GNUC_UNUSED gboolean send_close)
 {
 	SoupMessage *message = NULL;
 	SoupURI *base_uri = NULL;
@@ -381,7 +378,7 @@ dmap_connection_build_message (DMAPConnection * connection,
 
 #ifdef HAVE_LIBZ
 static void *
-g_zalloc_wrapper (voidpf opaque, uInt items, uInt size)
+g_zalloc_wrapper (G_GNUC_UNUSED voidpf opaque, uInt items, uInt size)
 {
 	if ((items != 0) && (size >= G_MAXUINT / items)) {
 		return Z_NULL;
@@ -393,7 +390,7 @@ g_zalloc_wrapper (voidpf opaque, uInt items, uInt size)
 }
 
 static void
-g_zfree_wrapper (voidpf opaque, voidpf address)
+g_zfree_wrapper (G_GNUC_UNUSED voidpf opaque, voidpf address)
 {
 	g_free (address);
 }
@@ -422,7 +419,7 @@ typedef struct
 	gpointer user_data;
 } DAAPResponseData;
 
-static void
+static gpointer
 actual_http_response_handler (DAAPResponseData * data)
 {
 	DMAPConnectionPrivate *priv;
@@ -609,13 +606,15 @@ actual_http_response_handler (DAAPResponseData * data)
 	g_object_unref (G_OBJECT (data->connection));
 	g_object_unref (G_OBJECT (data->message));
 	g_free (data);
+
+	return NULL;
 }
 
 static void
-http_response_handler (SoupSession * session,
+http_response_handler (G_GNUC_UNUSED SoupSession * session,
 		       SoupMessage * message, DAAPResponseData * data)
 {
-	int response_length;
+	goffset response_length;
 
 	if (message->status_code == SOUP_STATUS_CANCELLED) {
 		g_debug ("Message cancelled");
@@ -715,7 +714,7 @@ emit_progress_idle (DMAPConnection * connection)
 
 static void
 handle_server_info (DMAPConnection * connection,
-		    guint status, GNode * structure, gpointer user_data)
+		    guint status, GNode * structure, G_GNUC_UNUSED gpointer user_data)
 {
 	DMAPConnectionPrivate *priv = connection->priv;
 	DMAPStructureItem *item = NULL;
@@ -741,7 +740,7 @@ handle_server_info (DMAPConnection * connection,
 
 static void
 handle_login (DMAPConnection * connection,
-	      guint status, GNode * structure, gpointer user_data)
+	      guint status, GNode * structure, G_GNUC_UNUSED gpointer user_data)
 {
 	DMAPConnectionPrivate *priv = connection->priv;
 	DMAPStructureItem *item = NULL;
@@ -780,7 +779,7 @@ handle_login (DMAPConnection * connection,
 
 static void
 handle_update (DMAPConnection * connection,
-	       guint status, GNode * structure, gpointer user_data)
+	       guint status, GNode * structure, G_GNUC_UNUSED gpointer user_data)
 {
 	DMAPConnectionPrivate *priv = connection->priv;
 	DMAPStructureItem *item;
@@ -804,7 +803,7 @@ handle_update (DMAPConnection * connection,
 
 static void
 handle_database_info (DMAPConnection * connection,
-		      guint status, GNode * structure, gpointer user_data)
+		      guint status, GNode * structure, G_GNUC_UNUSED gpointer user_data)
 {
 	DMAPConnectionPrivate *priv = connection->priv;
 	DMAPStructureItem *item = NULL;
@@ -851,7 +850,7 @@ handle_database_info (DMAPConnection * connection,
 
 static void
 handle_song_listing (DMAPConnection * connection,
-		     guint status, GNode * structure, gpointer user_data)
+		     guint status, GNode * structure, G_GNUC_UNUSED gpointer user_data)
 {
 	DMAPConnectionPrivate *priv = connection->priv;
 	DMAPStructureItem *item = NULL;
@@ -992,7 +991,7 @@ compare_playlists_by_name (gconstpointer a, gconstpointer b)
 
 static void
 handle_playlists (DMAPConnection * connection,
-		  guint status, GNode * structure, gpointer user_data)
+		  guint status, GNode * structure, G_GNUC_UNUSED gpointer user_data)
 {
 	DMAPConnectionPrivate *priv = connection->priv;
 	GNode *listing_node;
@@ -1055,7 +1054,7 @@ handle_playlists (DMAPConnection * connection,
 
 static void
 handle_playlist_entries (DMAPConnection * connection,
-			 guint status, GNode * structure, gpointer user_data)
+			 guint status, GNode * structure, G_GNUC_UNUSED gpointer user_data)
 {
 	DMAPConnectionPrivate *priv = connection->priv;
 	DMAPPlaylist *playlist;
@@ -1115,7 +1114,9 @@ handle_playlist_entries (DMAPConnection * connection,
 
 static void
 handle_logout (DMAPConnection * connection,
-	       guint status, GNode * structure, gpointer user_data)
+	       G_GNUC_UNUSED guint status,
+               G_GNUC_UNUSED GNode * structure,
+               G_GNUC_UNUSED gpointer user_data)
 {
 	connection_disconnected (connection);
 
@@ -1658,8 +1659,7 @@ dmap_connection_dispose (GObject * object)
 			DMAPPlaylist *playlist = l->data;
 
 			/* FIXME: refstring: */
-			g_list_foreach (playlist->uris, (GFunc) g_free, NULL);
-			g_list_free (playlist->uris);
+			g_list_free_full (playlist->uris, g_free);
 			g_free (playlist->name);
 			g_free (playlist);
 			l->data = NULL;
