@@ -63,12 +63,8 @@ struct DMAPGstInputStreamPrivate
 	gboolean buffer_closed;	/* May close before decoding complete */
 };
 
-#define DMAP_GST_INPUT_STREAM_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), \
-					   DMAP_TYPE_GST_INPUT_STREAM, \
-					   DMAPGstInputStreamPrivate))
-
 static goffset
-dmap_gst_input_stream_tell (GSeekable * seekable)
+dmap_gst_input_stream_tell (G_GNUC_UNUSED GSeekable * seekable)
 {
 	/* FIXME: implement return current position in stream. */
 	g_error ("Not implemented");
@@ -76,16 +72,17 @@ dmap_gst_input_stream_tell (GSeekable * seekable)
 }
 
 static gboolean
-dmap_gst_input_stream_can_seek (GSeekable * seekable)
+dmap_gst_input_stream_can_seek (G_GNUC_UNUSED GSeekable * seekable)
 {
 	return TRUE;
 }
 
 static gboolean
-dmap_gst_input_stream_seek (GSeekable * seekable,
-			    goffset offset,
+dmap_gst_input_stream_seek (G_GNUC_UNUSED GSeekable * seekable,
+			    G_GNUC_UNUSED goffset offset,
 			    GSeekType type,
-			    GCancellable * cacellable, GError ** error)
+			    G_GNUC_UNUSED GCancellable * cacellable,
+                            GError ** error)
 {
 	// FIXME: implement: DMAPGstInputStream *stream;
 	// FIXME: implement: goffset absolute;
@@ -143,15 +140,16 @@ dmap_gst_input_stream_seek (GSeekable * seekable,
 }
 
 static gboolean
-dmap_gst_input_stream_can_truncate (GSeekable * seekable)
+dmap_gst_input_stream_can_truncate (G_GNUC_UNUSED GSeekable * seekable)
 {
 	return FALSE;
 }
 
 static gboolean
-dmap_gst_input_stream_truncate (GSeekable * seekable,
-				goffset offset,
-				GCancellable * cancellable, GError ** error)
+dmap_gst_input_stream_truncate (G_GNUC_UNUSED GSeekable * seekable,
+				G_GNUC_UNUSED goffset offset,
+				G_GNUC_UNUSED GCancellable * cancellable,
+                                GError ** error)
 {
 	g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
 		     "Cannot truncate DMAPGstInputStream");
@@ -301,9 +299,10 @@ static gssize
 dmap_gst_input_stream_read (GInputStream * stream,
 			    void *buffer,
 			    gsize count,
-			    GCancellable * cancellable, GError ** error)
+			    G_GNUC_UNUSED GCancellable * cancellable,
+                            G_GNUC_UNUSED GError ** error)
 {
-	int i;
+	gsize i;
 	DMAPGstInputStream *gst_stream = DMAP_GST_INPUT_STREAM (stream);
 	gint64 end_time;
 
@@ -346,9 +345,10 @@ dmap_gst_input_stream_read (GInputStream * stream,
 }
 
 static gssize
-dmap_gst_input_stream_skip (GInputStream * stream,
-			    gsize count,
-			    GCancellable * cancellable, GError ** error)
+dmap_gst_input_stream_skip (G_GNUC_UNUSED GInputStream * stream,
+			    G_GNUC_UNUSED gsize count,
+			    G_GNUC_UNUSED GCancellable * cancellable,
+                            G_GNUC_UNUSED GError ** error)
 {
 	g_error ("Not implemented");
 	return 0;
@@ -362,7 +362,8 @@ dmap_gst_input_stream_kill_pipeline (DMAPGstInputStream * stream)
 
 static gboolean
 dmap_gst_input_stream_close (GInputStream * stream,
-			     GCancellable * cancellable, GError ** error)
+			     G_GNUC_UNUSED GCancellable * cancellable,
+                             G_GNUC_UNUSED GError ** error)
 {
 	DMAPGstInputStream *gst_stream = DMAP_GST_INPUT_STREAM (stream);
 
@@ -379,54 +380,57 @@ dmap_gst_input_stream_close (GInputStream * stream,
 }
 
 static gssize
-dmap_gst_input_stream_read_finish (GInputStream * stream,
-				   GAsyncResult * result, GError ** error)
+dmap_gst_input_stream_read_finish (G_GNUC_UNUSED GInputStream * stream,
+				   G_GNUC_UNUSED GAsyncResult * result,
+                                   G_GNUC_UNUSED GError ** error)
 {
 	g_error ("Not implemented");
 	return 0;
 }
 
 static gssize
-dmap_gst_input_stream_skip_finish (GInputStream * stream,
-				   GAsyncResult * result, GError ** error)
+dmap_gst_input_stream_skip_finish (G_GNUC_UNUSED GInputStream * stream,
+				   G_GNUC_UNUSED GAsyncResult * result,
+                                   G_GNUC_UNUSED GError ** error)
 {
 	g_error ("Not implemented");
 	return 0;
 }
 
 static void
-dmap_gst_input_stream_close_async (GInputStream * stream,
-				   int io_priority,
-				   GCancellable * cancellabl,
-				   GAsyncReadyCallback callback,
-				   gpointer data)
+dmap_gst_input_stream_close_async (G_GNUC_UNUSED GInputStream * stream,
+				   G_GNUC_UNUSED int io_priority,
+				   G_GNUC_UNUSED GCancellable * cancellabl,
+				   G_GNUC_UNUSED GAsyncReadyCallback callback,
+				   G_GNUC_UNUSED gpointer data)
 {
 }
 
 static void
-dmap_gst_input_stream_read_async (GInputStream * stream,
-				  void *buffer,
-				  gsize count,
-				  int io_priority,
-				  GCancellable * cancellable,
-				  GAsyncReadyCallback callback,
-				  gpointer user_data)
+dmap_gst_input_stream_read_async (G_GNUC_UNUSED GInputStream * stream,
+				  G_GNUC_UNUSED void *buffer,
+				  G_GNUC_UNUSED gsize count,
+				  G_GNUC_UNUSED int io_priority,
+				  G_GNUC_UNUSED GCancellable * cancellable,
+				  G_GNUC_UNUSED GAsyncReadyCallback callback,
+				  G_GNUC_UNUSED gpointer user_data)
 {
 }
 
 static void
-dmap_gst_input_stream_skip_async (GInputStream * stream,
-				  gsize count,
-				  int io_priority,
-				  GCancellable * cancellabl,
-				  GAsyncReadyCallback callback,
-				  gpointer datae)
+dmap_gst_input_stream_skip_async (G_GNUC_UNUSED GInputStream * stream,
+				  G_GNUC_UNUSED gsize count,
+				  G_GNUC_UNUSED int io_priority,
+				  G_GNUC_UNUSED GCancellable * cancellabl,
+				  G_GNUC_UNUSED GAsyncReadyCallback callback,
+				  G_GNUC_UNUSED gpointer datae)
 {
 }
 
 static gboolean
-dmap_gst_input_stream_close_finish (GInputStream * stream,
-				    GAsyncResult * result, GError ** error)
+dmap_gst_input_stream_close_finish (G_GNUC_UNUSED GInputStream * stream,
+				    G_GNUC_UNUSED GAsyncResult * result,
+                                    G_GNUC_UNUSED GError ** error)
 {
 	g_error ("Not implemented");
 	return FALSE;
@@ -437,8 +441,6 @@ dmap_gst_input_stream_class_init (DMAPGstInputStreamClass * klass)
 {
 	GInputStreamClass *istream_class;
 
-	g_type_class_add_private (klass, sizeof (DMAPGstInputStreamPrivate));
-
 	istream_class = G_INPUT_STREAM_CLASS (klass);
 	istream_class->read_fn = dmap_gst_input_stream_read;
 	istream_class->skip = dmap_gst_input_stream_skip;
@@ -454,8 +456,6 @@ dmap_gst_input_stream_class_init (DMAPGstInputStreamClass * klass)
 static void
 dmap_gst_input_stream_init (DMAPGstInputStream * stream)
 {
-	stream->priv = DMAP_GST_INPUT_STREAM_GET_PRIVATE (stream);
-
 	stream->priv->buffer = g_queue_new ();
 	stream->priv->read_request = 0;
 	stream->priv->write_request = 0;
@@ -472,4 +472,5 @@ dmap_gst_input_stream_init (DMAPGstInputStream * stream)
 G_DEFINE_TYPE_WITH_CODE (DMAPGstInputStream, dmap_gst_input_stream,
 			 G_TYPE_INPUT_STREAM,
 			 G_IMPLEMENT_INTERFACE (G_TYPE_SEEKABLE,
-						dmap_gst_input_stream_seekable_iface_init));
+						dmap_gst_input_stream_seekable_iface_init)
+                         G_ADD_PRIVATE (DMAPGstInputStream));
