@@ -23,8 +23,8 @@
 #include <gst/gst.h>
 #include <gst/app/gstappsink.h>
 
-#include "gst-util.h"
 #include "dmap-gst-wav-input-stream.h"
+#include "gst-util.h"
 
 #define GST_APP_MAX_BUFFERS 1024
 
@@ -39,12 +39,8 @@ struct DMAPGstWAVInputStreamPrivate
 	GstElement *sink;
 };
 
-/* FIXME: See note in dmap-gst-input-stream.h */
-void dmap_gst_input_stream_new_buffer_cb (GstElement * element,
-					  DMAPGstInputStream * stream);
-
 static void
-pad_added_cb (GstElement * element,
+pad_added_cb (G_GNUC_UNUSED GstElement * element,
               GstPad * pad,
               GstElement *convert)
 {
@@ -224,25 +220,20 @@ dmap_gst_wav_input_stream_kill_pipeline (DMAPGstInputStream * stream)
 	gst_object_unref (GST_OBJECT (wav_stream->priv->pipeline));
 }
 
-G_DEFINE_TYPE (DMAPGstWAVInputStream, dmap_gst_wav_input_stream,
-	       DMAP_TYPE_GST_INPUT_STREAM)
+G_DEFINE_TYPE_WITH_PRIVATE (DMAPGstWAVInputStream, dmap_gst_wav_input_stream,
+                            DMAP_TYPE_GST_INPUT_STREAM)
 
-     static void
-	     dmap_gst_wav_input_stream_class_init (DMAPGstWAVInputStreamClass
-						   * klass)
+static void
+dmap_gst_wav_input_stream_class_init (DMAPGstWAVInputStreamClass * klass)
 {
 	DMAPGstInputStreamClass *parent_class =
 		DMAP_GST_INPUT_STREAM_CLASS (klass);
 
-	g_type_class_add_private (klass,
-				  sizeof (DMAPGstWAVInputStreamPrivate));
-
 	parent_class->kill_pipeline = dmap_gst_wav_input_stream_kill_pipeline;
 }
 
 static void
 dmap_gst_wav_input_stream_init (DMAPGstWAVInputStream * stream)
 {
-	stream->priv = DMAP_GST_WAV_INPUT_STREAM_GET_PRIVATE (stream);
-
+	stream->priv = dmap_gst_wav_input_stream_get_instance_private(stream);
 }
