@@ -23,17 +23,34 @@
 
 #include <glib.h>
 
+#define DMAP_HASH_SIZE 16
+
 G_BEGIN_DECLS
-	void dmap_hash_generate (short version_major,
-				 const guchar * url,
-				 guchar hash_select,
-				 guchar * out, gint request_id);
 
-#ifdef HAVE_CHECK
-#include <check.h>
+typedef struct DMAPHashContext
+{
+        guint32 buf[4];
+        guint32 bits[2];
+        unsigned char in[64];
+        gint version;
+} DMAPHashContext;
 
-Suite *dmap_test_daap_connection_suite (void);
-#endif
+void dmap_hash_progressive_init      (DMAPHashContext *context);
+
+void dmap_hash_progressive_update    (DMAPHashContext *context,
+                                      unsigned char const *buffer,
+                                      unsigned int length);
+
+void dmap_hash_progressive_final     (DMAPHashContext *context,
+                                      unsigned char digest[16]);
+
+void dmap_hash_progressive_to_string (const unsigned char *digest, gchar * string);
+
+void dmap_hash_generate              (short version_major,
+                                      const guchar *url,
+                                      guchar hash_select,
+                                      guchar *out,
+                                      gint request_id);
 
 G_END_DECLS
 #endif
