@@ -19,14 +19,13 @@
 #include "config.h"
 
 #include <stdio.h>
+#include <string.h>
 #include <glib.h>
 #include <dns_sd.h>
 #include <arpa/inet.h>
 
 #include "dmap-mdns-publisher.h"
 
-#define DMAP_MDNS_PUBLISHER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DMAP_TYPE_MDNS_PUBLISHER, DMAPMdnsPublisherPrivate))
-
 struct DMAPMdnsPublisherPrivate
 {
 	DNSServiceRef	 sdref;
@@ -41,7 +40,7 @@ enum {
 
 static guint signals [LAST_SIGNAL] = { 0, };
 
-G_DEFINE_TYPE (DMAPMdnsPublisher, dmap_mdns_publisher, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (DMAPMdnsPublisher, dmap_mdns_publisher, G_TYPE_OBJECT)
 
 static gpointer publisher_object = NULL;
 
@@ -55,16 +54,59 @@ dmap_mdns_publisher_error_quark (void)
 }
 
 gboolean
-dmap_mdns_publisher_rename_at_port (DMAPMdnsPublisher *publisher,
-				    guint	       port,
-                                    const char        *name,
-                                    GError           **error)
+dmap_mdns_publisher_rename_at_port (G_GNUC_UNUSED DMAPMdnsPublisher *publisher,
+				    G_GNUC_UNUSED guint	             port,
+                                    G_GNUC_UNUSED const char        *name,
+                                    G_GNUC_UNUSED GError           **error)
 {
 	g_error ("Not implemented");
 
         return TRUE;
 }
 
+static gchar *
+_build_txt_record(gboolean password_required, gchar **txt_records, uint16_t *txt_len)
+{
+	*txt_len = 0;
+
+	gchar **_txt_records;
+	for (_txt_records = txt_records; _txt_records && *_txt_records; _txt_records++) {
+		*txt_len += strlen(*_txt_records) + 1; // + 1 for req. len.
+		_txt_records++;
+	}
+
+	char password_size = 0;
+	if(TRUE == password_required) {
+		password_size = (char) strlen("Password=true") + 1;
+	} else {
+		password_size = (char) strlen("Password=false") + 1;
+	}
+	*txt_len += password_size;
+
+	size_t i = 0;
+	gchar *txt_record = g_malloc(*txt_len);
+
+	for (; txt_records && *txt_records; txt_records++) {
+		size_t len = strlen(*txt_records);
+
+		g_assert(len <= 255);
+
+		txt_record[i++] = (char)len;
+
+		memcpy(txt_record + i, *txt_records, len);
+		i += len;
+	}
+
+	txt_record[i++] = password_size - 1;
+	if(TRUE == password_required) {
+		strcpy(txt_record + i, "Password=true");
+	} else {
+		strcpy(txt_record + i, "Password=false");
+	}
+
+	return txt_record;
+}
+
 gboolean
 dmap_mdns_publisher_publish (DMAPMdnsPublisher *publisher,
                              const char          *name,
@@ -74,11 +116,13 @@ dmap_mdns_publisher_publish (DMAPMdnsPublisher *publisher,
 			     gchar              **txt_records,
                              GError             **error)
 {
+	gboolean fnval = TRUE;
+	uint16_t txt_len = 0;
+	char *txt_record = NULL;
 	int dns_err;
 
-	/* FIXME: does not do anything with txt_records yet */
-	if (txt_records != NULL)
-		g_warning ("dmap_mdns_publisher_publish() can not handle txt_records yet");
+	/* TODO: Unify txt_records and password_required to simplify build_txt_...? */
+	txt_record = _build_txt_record(password_required, txt_records, &txt_len);
 
 	g_warning ("%s %s %d", name, type_of_service, port);
 	if ((dns_err = DNSServiceRegister (&publisher->priv->sdref,
@@ -89,8 +133,8 @@ dmap_mdns_publisher_publish (DMAPMdnsPublisher *publisher,
 		NULL,
 		NULL,
 		htons (port),
-		0,
-		NULL,
+		txt_len,
+		txt_record,
 		NULL,
 		NULL)) != kDNSServiceErr_NoError) {
                 g_set_error (error,
@@ -101,18 +145,22 @@ dmap_mdns_publisher_publish (DMAPMdnsPublisher *publisher,
 		if (dns_err == kDNSServiceErr_NameConflict) {
 			g_signal_emit (publisher, signals[NAME_COLLISION], 0, publisher->priv->name);
 		}
-                return FALSE;
+		fnval = FALSE;
+		goto done;
         }
 
 	g_signal_emit (publisher, signals[PUBLISHED], 0, publisher->priv->name);
 
-        return TRUE;
+done:
+	g_free(txt_record);
+
+        return fnval;
 }
 
 gboolean
-dmap_mdns_publisher_withdraw (DMAPMdnsPublisher *publisher,
-			      guint port,
-                              GError             **error)
+dmap_mdns_publisher_withdraw (G_GNUC_UNUSED DMAPMdnsPublisher *publisher,
+			      G_GNUC_UNUSED                    guint port,
+                              G_GNUC_UNUSED GError           **error)
 {
 	g_error ("Not implemented");
 
@@ -120,10 +168,10 @@ dmap_mdns_publisher_withdraw (DMAPMdnsPublisher *publisher,
 }
 
 static void
-dmap_mdns_publisher_set_property (GObject         *object,
-                                     guint         prop_id,
-                                     const GValue *value,
-                                     GParamSpec   *pspec)
+dmap_mdns_publisher_set_property (GObject      *object,
+                                  guint         prop_id,
+                                  G_GNUC_UNUSED const GValue *value,
+                                  GParamSpec   *pspec)
 {
         switch (prop_id) {
         default:
@@ -133,10 +181,10 @@ dmap_mdns_publisher_set_property (GObject         *object,
 }
 
 static void
-dmap_mdns_publisher_get_property (GObject        *object,
-                                     guint        prop_id,
-                                     GValue      *value,
-                                     GParamSpec  *pspec)
+dmap_mdns_publisher_get_property (GObject    *object,
+                                  guint       prop_id,
+                                  G_GNUC_UNUSED GValue *value,
+                                  GParamSpec *pspec)
 {
         switch (prop_id) {
         default:
@@ -178,7 +226,7 @@ dmap_mdns_publisher_class_init (DMAPMdnsPublisherClass *klass)
 			      G_STRUCT_OFFSET (DMAPMdnsPublisherClass, published),
                               NULL,
                               NULL,
-                              g_cclosure_marshal_VOID__STRING,
+                              NULL,
                               G_TYPE_NONE,
                               1, G_TYPE_STRING);
         signals [NAME_COLLISION] =
@@ -188,17 +236,15 @@ dmap_mdns_publisher_class_init (DMAPMdnsPublisherClass *klass)
 			      G_STRUCT_OFFSET (DMAPMdnsPublisherClass, name_collision),
                               NULL,
                               NULL,
-                              g_cclosure_marshal_VOID__STRING,
+                              NULL,
                               G_TYPE_NONE,
                               1, G_TYPE_STRING);
-
-        g_type_class_add_private (klass, sizeof (DMAPMdnsPublisherPrivate));
 }
 
 static void
 dmap_mdns_publisher_init (DMAPMdnsPublisher *publisher)
 {
-        publisher->priv = DMAP_MDNS_PUBLISHER_GET_PRIVATE (publisher);
+	publisher->priv = dmap_mdns_publisher_get_instance_private(publisher);
 }
 
 DMAPMdnsPublisher *
