@@ -38,7 +38,7 @@ dmap_write_next_chunk (SoupMessage * message, ChunkData * cd)
 	if (read_size > 0) {
 		soup_message_body_append (message->response_body,
 					  SOUP_MEMORY_TAKE, chunk, read_size);
-		g_debug ("Read/wrote %ld bytes.", read_size);
+		g_debug ("Read/wrote %"G_GSSIZE_FORMAT" bytes.", read_size);
 	} else {
 		if (error != NULL) {
 			g_warning ("Error reading from input stream: %s",
@@ -53,7 +53,8 @@ dmap_write_next_chunk (SoupMessage * message, ChunkData * cd)
 }
 
 void
-dmap_chunked_message_finished (SoupMessage * message, ChunkData * cd)
+dmap_chunked_message_finished (G_GNUC_UNUSED SoupMessage * message,
+                               ChunkData * cd)
 {
 	g_debug ("Finished sending chunked file.");
 	g_input_stream_close (cd->stream, NULL, NULL);
