@@ -114,16 +114,14 @@ struct share_bitwise_t
 static void dmap_share_init (DMAPShare * share);
 static void dmap_share_class_init (DMAPShareClass * klass);
 
-G_DEFINE_ABSTRACT_TYPE (DMAPShare, dmap_share, G_TYPE_OBJECT)
-#define DMAP_SHARE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), \
-				   DMAP_TYPE_SHARE, DMAPSharePrivate));
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (DMAPShare, dmap_share, G_TYPE_OBJECT)
 
-     static gboolean
-	     _dmap_share_soup_auth_callback (SoupAuthDomain * auth_domain,
-					     SoupMessage * msg,
-					     const char *username,
-					     gpointer password,
-					     DMAPShare * share)
+static gboolean
+_dmap_share_soup_auth_callback (G_GNUC_UNUSED SoupAuthDomain * auth_domain,
+                                SoupMessage * msg,
+                                const char *username,
+                                gpointer password,
+                                DMAPShare * share)
 {
 	gboolean allowed;
 	const char *path;
@@ -687,8 +685,6 @@ dmap_share_class_init (DMAPShareClass * klass)
 							     "Set TXT-Records used for MDNS publishing",
 							     G_TYPE_STRV,
 							     G_PARAM_READWRITE));
-
-	g_type_class_add_private (klass, sizeof (DMAPSharePrivate));
 }
 
 static void
@@ -708,7 +704,7 @@ name_collision_adapter (DMAPMdnsPublisher * publisher,
 static void
 dmap_share_init (DMAPShare * share)
 {
-	share->priv = DMAP_SHARE_GET_PRIVATE (share);
+	share->priv = dmap_share_get_instance_private(share);
 
 	share->priv->revision_number = 5;
 	share->priv->auth_method = DMAP_SHARE_AUTH_METHOD_NONE;
@@ -778,7 +774,7 @@ _dmap_share_get_revision_number_from_query (GHashTable * query,
 gboolean
 _dmap_share_session_id_validate (DMAPShare * share,
 				 SoupClientContext * context,
-				 SoupMessage * message,
+				 G_GNUC_UNUSED SoupMessage * message,
 				 GHashTable * query, guint32 * id)
 {
 	guint32 session_id;
@@ -823,7 +819,8 @@ _dmap_share_session_id_validate (DMAPShare * share,
 }
 
 static guint32
-session_id_generate (DMAPShare * share, SoupClientContext * context)
+session_id_generate (G_GNUC_UNUSED DMAPShare * share,
+                     G_GNUC_UNUSED SoupClientContext * context)
 {
 	guint32 id;
 
@@ -863,7 +860,8 @@ _dmap_share_session_id_create (DMAPShare * share, SoupClientContext * context)
 
 void
 _dmap_share_session_id_remove (DMAPShare * share,
-			       SoupClientContext * context, guint32 id)
+			       G_GNUC_UNUSED SoupClientContext * context,
+                               guint32 id)
 {
 	g_hash_table_remove (share->priv->session_ids, GUINT_TO_POINTER (id));
 }
@@ -905,8 +903,9 @@ _dmap_share_uri_is_local (const char *text_uri)
 }
 
 gboolean
-_dmap_share_soup_auth_filter (SoupAuthDomain * auth_domain,
-			      SoupMessage * msg, gpointer user_data)
+_dmap_share_soup_auth_filter (G_GNUC_UNUSED SoupAuthDomain * auth_domain,
+			      SoupMessage * msg,
+                              G_GNUC_UNUSED gpointer user_data)
 {
 	const char *path;
 
@@ -926,7 +925,8 @@ _dmap_share_soup_auth_filter (SoupAuthDomain * auth_domain,
 
 void
 _dmap_share_published (DMAPShare * share,
-		       DMAPMdnsPublisher * publisher, const char *name)
+		       G_GNUC_UNUSED DMAPMdnsPublisher * publisher,
+                       const char *name)
 {
 	if (share->priv->name == NULL || name == NULL) {
 		return;
@@ -940,7 +940,8 @@ _dmap_share_published (DMAPShare * share,
 
 void
 _dmap_share_name_collision (DMAPShare * share,
-			    DMAPMdnsPublisher * publisher, const char *name)
+			    G_GNUC_UNUSED DMAPMdnsPublisher * publisher,
+                            const char *name)
 {
 	char *new_name = "FIXME";
 
@@ -960,10 +961,11 @@ _dmap_share_name_collision (DMAPShare * share,
 
 void
 _dmap_share_content_codes (DMAPShare * share,
-			   SoupServer * server,
+			   G_GNUC_UNUSED SoupServer * server,
 			   SoupMessage * message,
 			   const char *path,
-			   GHashTable * query, SoupClientContext * context)
+			   G_GNUC_UNUSED GHashTable * query,
+                           G_GNUC_UNUSED SoupClientContext * context)
 {
 /* MCCR content codes response
  * 	MSTT status
@@ -1005,10 +1007,11 @@ _dmap_share_content_codes (DMAPShare * share,
 
 void
 _dmap_share_login (DMAPShare * share,
-		   SoupServer * server,
+		   G_GNUC_UNUSED SoupServer * server,
 		   SoupMessage * message,
 		   const char *path,
-		   GHashTable * query, SoupClientContext * context)
+		   G_GNUC_UNUSED GHashTable * query,
+                   SoupClientContext * context)
 {
 /* MLOG login response
  * 	MSTT status
@@ -1031,7 +1034,7 @@ _dmap_share_login (DMAPShare * share,
 
 void
 _dmap_share_logout (DMAPShare * share,
-		    SoupServer * server,
+		    G_GNUC_UNUSED SoupServer * server,
 		    SoupMessage * message,
 		    const char *path,
 		    GHashTable * query, SoupClientContext * context)
@@ -1058,7 +1061,8 @@ _dmap_share_update (DMAPShare * share,
 		    SoupServer * server,
 		    SoupMessage * message,
 		    const char *path,
-		    GHashTable * query, SoupClientContext * context)
+		    GHashTable * query,
+                    G_GNUC_UNUSED SoupClientContext * context)
 {
 	guint revision_number;
 	gboolean res;
@@ -1142,7 +1146,8 @@ _dmap_share_parse_meta (GHashTable * query, struct DMAPMetaDataMap * mdm)
 }
 
 void
-_dmap_share_add_playlist_to_mlcl (gpointer id, DMAPContainerRecord * record,
+_dmap_share_add_playlist_to_mlcl (G_GNUC_UNUSED gpointer id,
+                                  DMAPContainerRecord * record,
 				  gpointer _mb)
 {
 	/* MLIT listing item
@@ -1422,7 +1427,7 @@ typedef struct
 } GroupInfo;
 
 static void
-group_items (gpointer key, DMAPRecord * record, GHashTable * groups)
+group_items (G_GNUC_UNUSED gpointer key, DMAPRecord * record, GHashTable * groups)
 {
 	gchar *album, *artist;
 	GroupInfo *group_info;
@@ -1457,17 +1462,18 @@ group_info_cmp (gconstpointer group1, gconstpointer group2)
 }
 
 static void
-debug_param (gpointer key, gpointer val, gpointer user_data)
+debug_param (gpointer key, gpointer val, G_GNUC_UNUSED gpointer user_data)
 {
 	g_debug ("%s %s", (char *) key, (char *) val);
 }
 
 void
-_dmap_share_ctrl_int (DMAPShare * share,
-		      SoupServer * server,
-		      SoupMessage * message,
+_dmap_share_ctrl_int (G_GNUC_UNUSED DMAPShare * share,
+		      G_GNUC_UNUSED SoupServer * server,
+		      G_GNUC_UNUSED SoupMessage * message,
 		      const char *path,
-		      GHashTable * query, SoupClientContext * context)
+		      GHashTable * query,
+                      G_GNUC_UNUSED SoupClientContext * context)
 {
 	g_debug ("Path is %s.", path);
 	if (query) {
@@ -1558,7 +1564,7 @@ write_next_mlit (SoupMessage * message, struct share_bitwise_t *share_bitwise)
 }
 
 static void
-chunked_message_finished (SoupMessage * message,
+chunked_message_finished (G_GNUC_UNUSED SoupMessage * message,
 			  struct share_bitwise_t *share_bitwise)
 {
 	g_debug ("Finished sending chunked data.");
@@ -1567,7 +1573,7 @@ chunked_message_finished (SoupMessage * message,
 	g_free (share_bitwise);
 }
 
-DMAPRecord *
+static DMAPRecord *
 g_hash_table_lookup_adapter (GHashTable * ht, guint id)
 {
 	/* NOTE: each time this is called by write_next_mlit(), the
