@@ -877,7 +877,7 @@ dmap_item_free (DMAPStructureItem * item)
 }
 
 static gboolean
-gnode_free_dmap_item (GNode * node, gpointer data)
+gnode_free_dmap_item (GNode * node, G_GNUC_UNUSED gpointer data)
 {
 	dmap_item_free ((DMAPStructureItem *) node->data);
 
@@ -911,21 +911,22 @@ dmap_content_code_string_as_int32 (const gchar * str)
 	union
 	{
 		gint32 i;
-		gchar str[4];
+		gchar str[5];
 	} u;
 
 	strncpy (u.str, str, 4);
+	u.str[4] = 0x00;
 
 	return g_htonl (u.i);
 }
 
 static gboolean
-print_dmap_item (GNode * node, gpointer data)
+print_dmap_item (GNode * node, G_GNUC_UNUSED gpointer data)
 {
 	DMAPStructureItem *item;
 	const gchar *name;
 	gchar *value;
-	gint i;
+	guint i;
 
 	for (i = 1; i < g_node_depth (node); i++) {
 		g_print ("\t");
